from typing import Protocol, type_check_only

def path() -> str: ...
@type_check_only
class _Writer(Protocol):
    def isatty(self) -> bool: ...
    def write(self, content: str, /) -> object: ...
    def flush(self) -> object: ...

class ProgressRenderer:
    def __init__(self, stream: _Writer, total_count: int) -> None: ...
    def render(self) -> None: ...
    def erase(self) -> None: ...
    def drop(self) -> None: ...
    @property
    def count(self) -> int: ...
    @count.setter
    def count(self, new_count: int) -> None: ...



import types
from collections.abc import Sequence
from importlib import abc, machinery
from typing_extensions import Self

def _should_skip(loader: abc.Loader) -> bool: ...

class AtherisMetaPathFinder(abc.MetaPathFinder):
    def __init__(
        self, include_packages: set[str], exclude_modules: set[str], enable_loader_override: bool, trace_dataflow: bool
    ) -> None: ...
    def find_spec(
        self, fullname: str, path: Sequence[str] | None, target: types.ModuleType | None = None
    ) -> machinery.ModuleSpec | None: ...
    def invalidate_caches(self) -> None: ...

class AtherisSourceFileLoader:
    def __init__(self, name: str, path: str, trace_dataflow: bool) -> None: ...
    def get_code(self, fullname: str) -> types.CodeType | None: ...

class AtherisSourcelessFileLoader:
    def __init__(self, name: str, path: str, trace_dataflow: bool) -> None: ...
    def get_code(self, fullname: str) -> types.CodeType | None: ...

def make_dynamic_atheris_loader(loader: abc.Loader | type[abc.Loader], trace_dataflow: bool) -> abc.Loader: ...

class HookManager:
    def __init__(
        self, include_packages: set[str], exclude_modules: set[str], enable_loader_override: bool, trace_dataflow: bool
    ) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(self, *args: object) -> None: ...

def instrument_imports(
    include: Sequence[str] | None = None, exclude: Sequence[str] | None = None, enable_loader_override: bool = True
) -> HookManager: ...



from collections.abc import Callable

def Setup(
    args: list[str],
    test_one_input: Callable[[bytes], None],
    **kwargs: bool | Callable[[bytes, int, int], str | bytes] | Callable[[bytes, bytes, int, int], str | bytes] | None,
) -> list[str]: ...
def Fuzz() -> None: ...
def Mutate(data: bytes, max_size: int) -> bytes: ...



import types
from typing import Final

PYTHON_VERSION: Final[tuple[int, int]]
CONDITIONAL_JUMPS: Final[list[str]]
UNCONDITIONAL_JUMPS: Final[list[str]]
ENDS_FUNCTION: Final[list[str]]
HAVE_REL_REFERENCE: Final[list[str]]
HAVE_ABS_REFERENCE: Final[list[str]]
REL_REFERENCE_IS_INVERTED: Final[list[str]]

def rel_reference_scale(opname: str) -> int: ...

REVERSE_CMP_OP: Final[list[int]]

def jump_arg_bytes(arg: int) -> int: ...
def add_bytes_to_jump_arg(arg: int, size: int) -> int: ...

class ExceptionTableEntry:
    def __init__(self, start_offset: int, end_offset: int, target: int, depth: int, lasti: bool) -> None: ...
    def __eq__(self, other: object) -> bool: ...

class ExceptionTable:
    def __init__(self, entries: list[ExceptionTableEntry]) -> None: ...
    def __eq__(self, other: object) -> bool: ...

def generate_exceptiontable(original_code: types.CodeType, exception_table_entries: list[ExceptionTableEntry]) -> bytes: ...




from setuptools import setup

setup(package_data={'atheris-stubs': ['__init__.pyi', 'function_hooks.pyi', 'import_hook.pyi', 'instrument_bytecode.pyi', 'utils.pyi', 'version_dependent.pyi', 'METADATA.toml', 'py.typed']})
